#include "config.h"
#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/wdt.h>
#include <can_lib.h>
#include <can_drv.h>
#include "Timer.h"
#include "LED.h"


void Init_Device(void)
{
	LED_INIT();
	TIMER_INIT();
	can_init (CAN_BAUDRATE);
	MCUSR = 0;
	wdt_disable();	//Watchdog abschalten
	sei(); //Interrupts Enabled
}

int main(void) 
{
	st_cmd_t message_out;
	uint8_t data[8] = {0x00,0x01,0x02,0x03,0x04,0x05,0x06,0x07};
	// Sende Massage
	message_out.cmd = CMD_TX;		// Message Typ einstellen senden, empfangen, remote...
	message_out.id.std = 0x120;		// CAN ID einstellen
	message_out.dlc = 8;			// Anzahl der Daten
	message_out.pt_data = &data[0];	// Den Zeiger der Message auf den Datenort einstellen
	message_out.ctrl.rtr = 0;   	// 0 = Data Frame, 1 = Remote Frame
	message_out.ctrl.ide = 0;   	// 0 = Standard Frame, 1 = extended Frame

	Init_Device();
	while(1){
		if (!(__Timer_H_cycle)){
			LED_TOGGLE();
			while(can_cmd(&message_out) != CAN_CMD_ACCEPTED);
			while(can_get_status(&message_out) == CAN_STATUS_NOT_COMPLETED);
			__Timer_H_cycle++; /*Reset im 1ms Takt ber Timer.h*/
		};
	}
	return 0;
}


